<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item :label="systemName+'号'" prop="usercode">
        <el-input
            v-model="queryParams.usercode"
            :placeholder="'请输入'+systemName+'号'"
            clearable
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="手机号" prop="mobile">
        <el-input
            v-model="queryParams.mobile"
            placeholder="请输入手机号"
            clearable
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-table v-loading="loading" :data="dynamicList" @selection-change="handleSelectionChange">
      <el-table-column label="ID" align="center" prop="id"/>
      <el-table-column label="置顶" align="center" prop="sort">
        <template v-slot="scope">
          <el-button v-if="scope.row.sort === 1" size="mini" type="warning"  @click="handleUnTop(scope.row)">取消置顶</el-button>
          <el-button v-else-if="!haveTop && scope.row.sort !== 1" size="mini" type="primary"  @click="handleTop(scope.row)" >置顶</el-button>
          <span v-else>-</span>
        </template>
      </el-table-column>
      <el-table-column :label="systemName+'号'" align="center" prop="usercode"/>
      <el-table-column label="手机号" align="center" prop="mobile"/>
      <el-table-column label="昵称" align="center" prop="nickname"/>
      <el-table-column label="头像" align="center" prop="avatar">
        <template v-slot="scope">
          <image-avatar :src="scope.row.avatar"/>
        </template>
      </el-table-column>
      <el-table-column label="城市" align="center" prop="city"/>
      <el-table-column label="图片" align="center" prop="content" >
        <template v-slot="scope">
           <span v-for='val in scope.row.dynamicImageList'>
              <image-preview :src="val.url" height="40px" width="40px"  /> &nbsp;
            </span>
        </template>
      </el-table-column>
      <el-table-column label="内容" align="center" prop="content" show-overflow-tooltip/>
      <el-table-column label="发布时间" align="center" prop="createTime" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template v-slot="scope">
          <el-button
              size="mini"
              type="text"
              icon="el-icon-delete"
              @click="handleDelete(scope.row)"
              v-hasPermi="['cai:dynamic:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
  </div>
</template>

<script>
import {
  batchAuditDynamic,
  delDynamic,
  dynamicSelectTop,
  dynamicTop,
  dynamicUnTop,
  listDynamic,
  updateDynamic
} from "@/api/cai/dynamic";
import {auditStatusList} from "@/constant/statusMap";

export default {
  name: "Dynamic",
  data() {
    return {
      systemName: process.env.VUE_APP_SYSTEM_HOME,
      auditStatusList,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 主播动态表格数据
      dynamicList: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        auditStatus: 2,
        mobile: undefined,
        usercode: undefined,
      },
      haveTop: true,
    };
  },
  created() {
    this.getList();
    this.getSelectTop();
  },
  methods: {
    /** 查询主播动态列表 */
    getList() {
      this.loading = true;
      listDynamic(this.queryParams).then(response => {
        this.dynamicList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    handleAudit(row,auditStatus){
      let message = auditStatus === 3 ? "通过" : "不通过";
      this.$modal.confirm('是否确认'+message+'动态编号为"' + row.id + '"的数据项？').then(() => {
        this.loading = true;
        return updateDynamic({
          id: row.id,
          auditStatus: auditStatus
        });
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("操作成功");
      }).catch(() => {
      }).finally(() => {
        this.loading = false;
      });
    },
    handleBatchAudit(auditStatus){
      const ids = this.ids;
      this.$modal.confirm('是否确认批量审核通过动态编号为"' + ids + '"的数据项？').then(() => {
        this.loading = true;
        return batchAuditDynamic({
          "ids": ids,
          auditStatus: auditStatus
        });
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("操作成功");
      }).catch(() => {
      }).finally(() => {
        this.loading = false;
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除主播动态编号为"' + ids + '"的数据项？').then(() => {
        this.loading = true;
        return delDynamic(ids);
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      }).finally(() => {
        this.loading = false;
      });
    },
    handleTop(row){
      this.loading = true;
      dynamicTop(row.id).then(res => {
        this.loading = false;
        this.getSelectTop();
        this.getList();
        this.$modal.msgSuccess("置顶成功");
      }).finally(() => {
        this.loading = false;
      })
    },
    handleUnTop(row){
      this.loading = true;
      dynamicUnTop(row.id).then(res => {
        this.loading = false;
        this.getSelectTop();
        this.getList();
        this.$modal.msgSuccess("取消置顶成功");
      }).finally(() => {
        this.loading = false;
      })
    },
    getSelectTop(){
      dynamicSelectTop().then(res => {
        this.haveTop = res.data.exists
      })
    }
  }
};
</script>
